@@ -877,6 +877,7 @@ class Trait(str, Enum):
     protoMerlinNPChargeBlock = "protoMerlinNPChargeBlock"
     valkyrie = "valkyrie"
     immuneToPigify = "immuneToPigify"
+    summerModeServant = "summerModeServant"
 
 
 TRAIT_NAME: dict[int, Trait] = {
@@ -1037,6 +1038,7 @@ TRAIT_NAME: dict[int, Trait] = {
     2835: Trait.immuneToPigify,
     2836: Trait.protoMerlinNPChargeBlock,
     2837: Trait.valkyrie,
+    2838: Trait.summerModeServant,
     # 2xxx: CQ or Story quests buff
     3000: Trait.attackPhysical,  # Normal attack, including NP
     3001: Trait.attackProjectile,
